|PyPI Version| |Python Versions|

Ansible Windows Compat
======================

Initial work on a compatibility library to allow Ansible modules written in
Python to run on a Windows target.  Only planned to support Ansible v2, and so
far only ping works.


.. |PyPI Version| image:: https://img.shields.io/pypi/v/ansible-windows-compat.svg
   :target: https://pypi.python.org/pypi/ansible-windows-compat
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/ansible-windows-compat.svg
   :target: https://pypi.python.org/pypi/ansible-windows-compat
